@@ -32,13 +32,36 @@ public:
 
 private slots:
     void declareFunction();
+    void declareBaseTypeFunction();
+    void declareSemiReservedFunction();
     void declareVar();
     void varTypehint();
     void declareClass();
+    void declareBaseTypeClass();
+    void declareClassWithSemiReservedMethod();
+    void declareClassWithBaseTypeMethod();
     void classMemberVar();
+    void classMemberVarAfterUse();
+    void classMemberVarDocBlockType();
     void declareTypehintFunction();
+    void declareVariadicFunction();
+    void declareTypehintVariadicFunction();
+    void declareTypehintObjectFunction();
     void declareTypehintArrayFunction();
     void declareTypehintCallableFunction();
+    void functionWithCallableAndFunctionReturn();
+    void declareTypehintIterableFunction();
+    void declareTypehintBoolFunction();
+    void declareTypehintFloatFunction();
+    void declareTypehintIntFunction();
+    void declareTypehintStringFunction();
+    void declareNullableTypehintArrayFunction();
+    void declareNullableTypehintMixedFunction();
+    void declareTypehintNullableIterableFunction();
+    void declareTypehintWithPhpdocFunction();
+    void returnTypeGenerator_data();
+    void returnTypeGenerator();
+    void returnTypeGeneratorDelegation();
     void returnTypeClass();
     void declarationReturnType();
     void declarationReturnTypeInRecursingFunction();
@@ -47,6 +70,9 @@ private slots:
     void declarationReturnTypeDocBlock();
     void declarationReturnTypeDocBlockIntegral();
     void declarationReturnTypeClassChain();
+    void declarationReturnTypeTypehint();
+    void declarationReturnTypeTypehintVoid();
+    void declarationReturnTypeTypehintObject();
     void classImplementsInterface();
     void classExtends();
     void staticMethod();
@@ -60,10 +86,14 @@ private slots:
     void ownStaticMemberVariable();
     void classConst();
     void classConst_data();
+    void semiReservedClassConst();
     void fileConst();
     void fileConst_data();
+    void semiReservedFileConst();
     void define();
     void defaultFunctionParam();
+    void defaultFunctionParamWithTypehint();
+    void nullDefaultFunctionParamWithTypehint();
     void globalFunction();
     void globalVariableFromInternalFunctions();
     void newObjectFromOtherFile();
@@ -96,6 +126,7 @@ private slots:
     void superglobalInFunction();
     void returnWithoutFunction();
     void circularInheritance();
+    void circularInterface();
     void findDeclarations();
     void memberTypeAfterMethod();
     void catchDeclaration();
@@ -128,7 +159,10 @@ private slots:
     void upcommingClassInString();
     void namespaces();
     void namespacesNoCurly();
+    void namespacesBaseType();
     void useNamespace();
+    void useBaseTypeNamespace();
+    void useNamespaceBaseTypeAlias();
     void namespaceStaticVar();
     void namespacedCatch();
     void errorRecovery_data();
@@ -142,11 +176,24 @@ private slots:
     void closureParser();
     void closures();
     void closureEmptyUse();
+    void iifeParser();
+    void iife();
     void gotoTest();
     void ternary();
     void bug296709();
     void declareFinalMethod();
     void testTodoExtractor();
+    void useThisAsArray();
+    void wrongUseOfThisAsArray();
+    void staticFunctionClassPhp54();
+    void functionArgumentUnpacking_data();
+    void functionArgumentUnpacking();
+    void illegalExpression_data();
+    void illegalExpression();
+    void printExpression_data();
+    void printExpression();
+    void generatorAssignment();
+    void generatorClosure();
 };
 
 }
