@@ -32,6 +32,7 @@
 #include <interfaces/icore.h>
 #include <interfaces/ilanguagecontroller.h>
 #include <interfaces/icompletionsettings.h>
+#include <language/editor/documentrange.h>
 
 namespace Php
 {
@@ -114,7 +115,7 @@ TokenStream* ParseSession::tokenStream() const
 
 Parser* ParseSession::createParser(int initialState)
 {
-    Parser* parser = new Parser;
+    auto* parser = new Parser;
     parser->setTokenStream(m_tokenStream);
     parser->setMemoryPool(m_pool);
     parser->setDebug(m_debug);
@@ -134,8 +135,8 @@ bool ParseSession::parse(Php::StartAst** ast)
         qCDebug(PARSER) << "Successfully parsed";
         *ast = phpAst;
     } else {
-        *ast = 0;
-        parser->expectedSymbol(AstNode::StartKind, "start");
+        *ast = nullptr;
+        parser->expectedSymbol(AstNode::StartKind, QStringLiteral("start"));
         qCDebug(PARSER) << "Couldn't parse content";
     }
     m_problems << parser->problems();
