@@ -69,7 +69,7 @@ void PhpUnitProvider::updateReady(const IndexedString& document, const Reference
 
     DUChainReadLocker lock;
     if (!context) {
-        qCDebug(TESTPROVIDER) << "Recieved null context for file: " << document;
+        qCDebug(TESTPROVIDER) << "Received null context for file: " << document;
         return;
     }
 
@@ -98,8 +98,6 @@ void PhpUnitProvider::updateReady(const IndexedString& document, const Reference
 
 void PhpUnitProvider::processContext(ReferencedTopDUContext referencedContext)
 {
-    qCDebug(TESTPROVIDER);
-
     TopDUContext* context = referencedContext.data();
 
     if (!context) {
